@@ -30,12 +30,26 @@ class RibbonBar(QtWidgets.QFrame):
     #: heights of the ribbon elements
     _ribbonHeight = 240
 
-    def __init__(self, title='PyQtRibbon', parent=None):
+    @typing.overload
+    def __init__(self, title: str = '', parent=None):
+        pass
+
+    @typing.overload
+    def __init__(self, parent=None):
+        pass
+
+    def __init__(self, *args, **kwargs):
         """Create a new ribbon.
 
         :param title: The title of the ribbon.
         :param parent: The parent widget of the ribbon.
         """
+        if (args and not isinstance(args[0], QtWidgets.QWidget)) or (kwargs and 'title' in kwargs):
+            title = args[0] if len(args) > 0 else kwargs.get('title', '')
+            parent = kwargs.get('parent', None)
+        else:
+            title = ''
+            parent = args[1] if len(args) > 1 else kwargs.get('parent', None)
         super().__init__(parent)
         self._categories = []
         self.setFixedHeight(self._ribbonHeight)
@@ -188,6 +202,13 @@ class RibbonBar(QtWidgets.QFrame):
         :param height: The height to set.
         """
         self._titleWidget.setRightToolBarHeight(height)
+        
+    def helpRibbonButton(self) -> QtWidgets.QToolButton:
+        """Return the help button of the ribbon.
+
+        :return: The help button of the ribbon.
+        """
+        return self._titleWidget.helpRibbonButton()
 
     def setHelpButtonIcon(self, icon: QtGui.QIcon):
         """Set the icon of the help button.
@@ -200,6 +221,24 @@ class RibbonBar(QtWidgets.QFrame):
         """Remove the help button from the ribbon."""
         self._titleWidget.removeHelpButton()
 
+    def collapseRibbonButton(self) -> QtWidgets.QToolButton:
+        """Return the collapse ribbon button.
+
+        :return: The collapse ribbon button.
+        """
+        return self._titleWidget.collapseRibbonButton()
+
+    def setCollapseButtonIcon(self, icon: QtGui.QIcon):
+        """Set the icon of the min button.
+
+        :param icon: The icon to set.
+        """
+        self._titleWidget.setCollapseButtonIcon(icon)
+
+    def removeCollapseButton(self):
+        """Remove the min button from the ribbon."""
+        self._titleWidget.removeCollapseButton()
+
     def categories(self) -> typing.List[RibbonCategory]:
         """Return a list of categories of the ribbon.
 
@@ -304,24 +343,6 @@ class RibbonBar(QtWidgets.QFrame):
         self.tabBar().setCurrentIndex(index)
         self._stackedWidget.setCurrentIndex(index)
 
-    def collapseRibbonButton(self) -> QtWidgets.QToolButton:
-        """Return the collapse ribbon button.
-
-        :return: The collapse ribbon button.
-        """
-        return self._titleWidget.collapseRibbonButton()
-
-    def setCollapseButtonIcon(self, icon: QtGui.QIcon):
-        """Set the icon of the min button.
-
-        :param icon: The icon to set.
-        """
-        self._titleWidget.setCollapseButtonIcon(icon)
-
-    def removeCollapseButton(self):
-        """Remove the min button from the ribbon."""
-        self._titleWidget.removeCollapseButton()
-
     def minimumSizeHint(self) -> QtCore.QSize:
         """Return the minimum size hint of the widget.
 
